"""Collection of various django related test utilities."""

__version__ = '0.6.0'


def load_tests(loader, tests, pattern):
    # Only consider tests within the tests folder. Otherwise the testcases module
    # produces conflicts with the standard pattern.
    return loader.discover(f'{__path__[0]}/tests', top_level_dir=__path__[0])



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

import pathlib
import sys


project_root_path = pathlib.Path(__file__).parents[2]
sys.path.insert(0, str(project_root_path))
from anfema_django_testutils import __version__ as version  # noqa: E402


# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'anfema-django-testutils'
copyright = '2022, anfema GmbH'
author = 'anfema GmbH'
release = version

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'sphinx_rtd_theme',
    'sphinx_copybutton',
    'sphinx.ext.autodoc',
    'sphinx_autodoc_typehints',
    'sphinx.ext.intersphinx',
    'm2r2',
]

source_suffix = ['.rst', '.md']

templates_path = ['_templates']
exclude_patterns = []

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_static_path = ['_static']
html_theme = 'sphinx_rtd_theme'
html_theme_options = {
    'display_version': True,
    'navigation_depth': 1,
}

autodoc_member_order = 'bysource'

copybutton_prompt_text = r'>>> |\.\.\. |\$ |In \[\d*\]: | {2,5}\.\.\.: | {5,8}: '
copybutton_prompt_is_regexp = True

autodoc_mock_imports = ["django"]

intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
    'django': ('https://docs.djangoproject.com/en/stable/', 'https://docs.djangoproject.com/en/stable/_objects/'),
}



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class AnfemaDjangoTestutilsConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "anfema_django_testutils"
    label = "anfema_django_testutils"
    verbose_name = _("anfema django testutils")



from __future__ import annotations

from functools import lru_cache
from typing import TYPE_CHECKING

from django.conf import settings
from django.dispatch import receiver
from django.test.signals import setting_changed


if TYPE_CHECKING:
    from typing import Any, Dict

CONFIG_DEFAULTS = {
    "TEST_REPORT_DIR": "test-report",
    "TEST_REPORT_HTML_TEMPLATE": "test-results-template.html",
    "TEST_REPORT_CSS": "test-results.css",
    "COVERAGE_REPORT_ENABLED": True,
    "HTML_RESULTS_ENABLED": True,
    "TEST_REPORT_TITLE": "Test Results",
}


@lru_cache()
def get_config() -> Dict[str, Any]:
    """Returns the current configuration"""
    return {conf: getattr(settings, conf, default) for conf, default in CONFIG_DEFAULTS.items()}


@receiver(setting_changed)
def update_testrunner_config(*, setting, **kwargs) -> None:
    """Refresh configuration when overriding settings."""
    if setting in CONFIG_DEFAULTS:
        get_config.cache_clear()
